#!/bin/bash

if [[ !( $(playerctl status) ) ]]; then
  echo "Run tuijam or some other player"
  exit 1
fi

if [[ $(playerctl status) != "Playing" ]]; then
  playerctl next
fi

workdir="$(mktemp -d playlist-XXXXXX)"
pushd "$workdir"

index=0

playlist_title="playlist"

function cleanup_and_exit() {
  rm -fv "current.mp3" "bg.png" "cover.jpg" "cover.png"
  popd
  mv "$workdir" "$playlist_title"
}

trap "cleanup_and_exit" EXIT

while [[ "$(playerctl status)" = "Playing" ]];do
  title="$(playerctl metadata xesam:title)"
  artist="$(playerctl metadata xesam:artist)"
  artUrl="$(playerctl metadata mpris:artUrl)"
  url="$(playerctl metadata xesam:url)"

  if [[ "${index}" = "0" ]];then
    playlist_title="Radio ${artist} - ${title}"
  fi

  # Downloading song and album cover
  wget "${url}" -O "current.mp3"
  wget "${artUrl}" -O "cover.jpg"

  # Processing background
  music_bg test "cover.jpg" --output "cover.png"

  convert -background '#0008' -gravity center \
    -fill white -size 800x70 caption:"${artist} - ${title}" \
    "cover.png" +swap -gravity south -geometry +0+200 -composite "bg.png"
  
  rm -fv "cover.jpg" "cover.png"

  ffmpeg -r 1 -loop 1 -i "bg.png" -i "current.mp3" \
    -map 0:v -map 1:a \
    -c:v libx264 -crf 23 -g 60 \
    -c:a aac \
    -vf "scale=-1:720,pad=ceil(iw/2)*2:ceil(ih/2)*2" \
    -maxrate 2M -bufsize 2M \
    -preset ultrafast -pix_fmt yuv420p \
    -framerate 30 -probesize 42M \
    -movflags faststart \
    -shortest -y -strict -2 "${index}.mp4"

  index=$((index + 1))
  if ! (playerctl next);then
    break
  fi
done
